#
# spec file for package openQA
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# can't use linebreaks here!
%define openqa_services openqa-webui.service openqa-gru.service openqa-websockets.service openqa-scheduler.service openqa-resource-allocator.service
%define openqa_worker_services openqa-worker.target openqa-slirpvde.service openqa-vde_switch.service
%if %{undefined tmpfiles_create}
%define tmpfiles_create() \
%{_bindir}/systemd-tmpfiles --create %{?*} || : \
%{nil}
%endif
%if 0%{?suse_version} >= 1500
%ifarch x86_64
%bcond_without tests
%else
%bcond_with tests
%endif
%else
%bcond_with tests
%endif
# runtime requirements that also the testsuite needs
%define t_requires perl(DBD::Pg) perl(DBIx::Class) perl(Config::IniFiles) perl(SQL::Translator) perl(Date::Format) perl(File::Copy::Recursive) perl(DateTime::Format::Pg) perl(Net::OpenID::Consumer) perl(Mojolicious::Plugin::RenderFile) perl(Mojolicious::Plugin::AssetPack) perl(aliased) perl(Config::Tiny) perl(DBIx::Class::DynamicDefault) perl(DBIx::Class::Schema::Config) perl(DBIx::Class::Storage::Statistics) perl(IO::Socket::SSL) perl(Data::Dump) perl(DBIx::Class::OptimisticLocking) perl(Text::Markdown) perl(Net::DBus) perl(IPC::Run) perl(Archive::Extract) perl(CSS::Minifier::XS) perl(JavaScript::Minifier::XS) perl(Time::ParseDate) perl(Sort::Versions) perl(Mojo::RabbitMQ::Client) perl(BSD::Resource) perl(Cpanel::JSON::XS) perl(Pod::POM) perl(Mojo::IOLoop::ReadWriteProcess) perl(Minion) perl(Mojo::Pg)
Name:           openQA
Version:        4.5.1525548058.3f6bb61a
Release:        lp150.1.1
Summary:        The openQA web-frontend, scheduler and tools
License:        GPL-2.0+
Group:          Development/Tools/Other
Url:            http://os-autoinst.github.io/openQA/
Source0:        %{name}-%{version}.tar.xz
# a workaround for set_version looking at random files (so we can't name it .tar.xz)
# use update-cache to update it
Source1:        cache.txz
Source101:      update-cache.sh
BuildRequires:  %{t_requires}
BuildRequires:  fdupes
BuildRequires:  os-autoinst
BuildRequires:  systemd
# critical bug fix
BuildRequires:  perl(DBIx::Class) >= 0.082801
BuildRequires:  perl(Minion) >= 9.02
BuildRequires:  perl(Mojolicious) >= 7.24
BuildRequires:  perl(Mojolicious::Plugin::AssetPack) >= 1.36
BuildRequires:  rubygem(sass)
Requires:       dbus-1
Requires:       perl(Minion) >= 9.02
# needed for test suite
Requires:       git-core
Requires:       openQA-client = %{version}
Requires:       openQA-common = %{version}
# needed for saving needles optimized
Requires:       optipng
Requires:       perl(DBIx::Class) >= 0.082801
# needed for openid support
Requires:       perl(LWP::Protocol::https)
Requires:       perl(URI)
# we need to have the same sha1 as expected
%requires_eq    perl-Mojolicious-Plugin-AssetPack
Recommends:     %{name}-local-db
Requires(post): coreutils
Requires(post): perl(DBIx::Class::DeploymentHandler)
Requires(post): perl(SQL::SplitStatement)
Recommends:     apache2
Recommends:     apparmor-profiles
Recommends:     apparmor-utils
Recommends:     logrotate
BuildRequires:  postgresql-server
BuildArch:      noarch
ExcludeArch:    i586
%{?systemd_requires}
%if %{with tests}
BuildRequires:  chromedriver
BuildRequires:  chromium
BuildRequires:  glibc-locale
# pick a font so chromium has something to render - doesn't matter so much
BuildRequires:  dejavu-fonts
BuildRequires:  google-roboto-fonts
BuildRequires:  perl-App-cpanminus
BuildRequires:  perl(DBD::SQLite)
BuildRequires:  perl(Mojo::RabbitMQ::Client)
BuildRequires:  perl(Perl::Critic)
BuildRequires:  perl(Perl::Tidy)
BuildRequires:  perl(Selenium::Remote::Driver) >= 1.20
BuildRequires:  perl(Test::Compile)
BuildRequires:  perl(Test::MockObject)
BuildRequires:  perl(Test::Warnings)
%endif
%if 0%{?suse_version} >= 1330
Requires(pre):  group(nogroup)
%endif

%description
openQA is a testing framework that allows you to test GUI applications on one
hand and bootloader and kernel on the other. In both cases, it is difficult to
script tests and verify the output. Output can be a popup window or it can be
an error in early boot even before init is executed.

openQA is an automated test tool that makes it possible to test the whole
installation process of an operating system. It uses virtual machines to
reproduce the process, check the output (both serial console and screen) in
every step and send the necessary keystrokes and commands to proceed to the
next. openQA can check whether the system can be installed, whether it works
properly in 'live' mode, whether applications work or whether the system
responds as expected to different installation options and commands.

Even more importantly, openQA can run several combinations of tests for every
revision of the operating system, reporting the errors detected for each
combination of hardware configuration, installation options and variant of the
operating system.

%package common
Summary:        The openQA common tools for web-frontend and workers
Group:          Development/Tools/Other
Requires:       %{t_requires}
Requires:       perl(Mojolicious) >= 7.24

%description common
This package contain shared resources for openQA web-frontend and
openQA workers.

%package worker
Summary:        The openQA worker
Group:          Development/Tools/Other
Requires:       openQA-client = %{version}
Requires:       os-autoinst < 5
Requires:       perl(DBD::SQLite)
Requires:       perl(Mojo::IOLoop::ReadWriteProcess) > 0.19
Requires:       perl(SQL::SplitStatement)
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         openQA-common = %{version}
Requires(post): coreutils
Requires(post): os-autoinst >= 4.4
Recommends:     qemu
%if 0%{?suse_version} >= 1330
Requires(pre):  group(nogroup)
%endif

%description worker
The openQA worker manages test engine (provided by os-autoinst package).

%package client
Summary:        Client tools for remote openQA management
Group:          Development/Tools/Other
Requires:       perl(Config::IniFiles)
Requires:       perl(Cpanel::JSON::XS)
Requires:       perl(Data::Dump)
Requires:       perl(Getopt::Long)
Requires:       perl(Mojolicious)

%description client
Tools and support files for openQA client script. Client script is
a convenient helper for interacting with openQA webui REST API.

%package local-db
Summary:        Helper package to ease setup of postgresql DB
Group:          Development/Tools/Other
Requires:       %name
Requires:       postgresql-server
Supplements:    packageand(%name:postgresql-server)

%description local-db
You only need this package if you have a local postgresql server
next to the webui.

%package doc
Summary:        The openQA documentation
Group:          Development/Tools/Other

%description doc
Documentation material covering installation, configuration, basic test writing, etc.
Covering both openQA and also os-autoinst test engine.

%prep
%setup -q -a1

%build
make %{?_smp_mflags}

%check
#for double checking
%if %{with tests}
cpanm --installdeps --with-feature=test .
%endif

# we don't really need the tidy test
rm -f t/00-tidy.t

%if %{with tests}
#make test
rm -rf %{buildroot}/DB
export LC_ALL=en_US.UTF-8
./t/test_postgresql %{buildroot}/DB
export TEST_PG="DBI:Pg:dbname=openqa_test;host=%{buildroot}/DB"
MOJO_LOG_LEVEL=debug OBS_RUN=1 prove -rv || true
pg_ctl -D %{buildroot}/DB stop
rm -rf %{buildroot}/DB
%endif

%install
export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
%make_install

mkdir -p %{buildroot}%{_datadir}/openqa%{_sysconfdir}/openqa
ln -s %{_sysconfdir}/openqa/openqa.ini %{buildroot}%{_datadir}/openqa%{_sysconfdir}/openqa/openqa.ini
ln -s %{_sysconfdir}/openqa/database.ini %{buildroot}%{_datadir}/openqa%{_sysconfdir}/openqa/database.ini
mkdir -p %{buildroot}%{_bindir}
ln -s %{_datadir}/openqa/script/client %{buildroot}%{_bindir}/openqa-client
ln -s %{_datadir}/openqa/script/clone_job.pl %{buildroot}%{_bindir}/openqa-clone-job
ln -s %{_datadir}/openqa/script/dump_templates %{buildroot}%{_bindir}/openqa-dump-templates
ln -s %{_datadir}/openqa/script/load_templates %{buildroot}%{_bindir}/openqa-load-templates

cd %{buildroot}
grep -rl %{_bindir}/env . | while read file; do
  sed -e 's,%{_bindir}/env perl,%{_bindir}/perl,' -i $file
done
mkdir -p %{buildroot}%{_sbindir}
for i in webui gru worker resource-allocator scheduler websockets slirpvde vde_switch; do
	ln -s ../sbin/service %{buildroot}%{_sbindir}/rcopenqa-$i
done
#
install -D -m 644 /dev/null %{buildroot}%{_localstatedir}/log/openqa
install -m 0644 %{_sourcedir}/openQA.changes %{buildroot}%{_datadir}/openqa/public/Changelog
#
mkdir %{buildroot}%{_localstatedir}/lib/openqa/pool/1
mkdir %{buildroot}%{_localstatedir}/lib/openqa/cache
#
%fdupes %{buildroot}/%{_prefix}

%pre
if ! getent passwd geekotest > /dev/null; then
  %{_sbindir}/useradd -r -g nogroup -c "openQA user" \
    -d %{_localstatedir}/lib/openqa geekotest 2>/dev/null || :
fi

%service_add_pre %{openqa_services}

%pre common
if [ "$1" = 1 ]; then
  # upgrade from openQA -> openQA-common (before -> after package split)
  # old data needs to be moved to new locations else cpio fail during package deploying
  if [ -d "%{_localstatedir}/lib/openqa/" -a ! -d "%{_localstatedir}/lib/openqa/share" ]; then
    echo "### performing migration of openQA data"
    mkdir "%{_localstatedir}/lib/openqa/share"
    if [ -e "%{_localstatedir}/lib/openqa/factory" ]; then
      echo "### moving %{_localstatedir}/lib/openqa/factory to %{_localstatedir}/lib/openqa/share/"
      mv "%{_localstatedir}/lib/openqa/factory" "%{_localstatedir}/lib/openqa/share/"
    fi
  fi
fi

%pre worker
if ! getent passwd _openqa-worker > /dev/null; then
  %{_sbindir}/useradd -r -g nogroup -c "openQA worker" \
    -d %{_localstatedir}/lib/empty _openqa-worker 2>/dev/null || :
  # might fail for non-kvm workers (qemu package owns the group)
  %{_sbindir}/usermod _openqa-worker -a -G kvm || :
fi

%service_add_pre %{openqa_worker_services}

%post
# install empty log file
if [ ! -e %{_localstatedir}/log/openqa ]; then
        install -D -m 644 -o geekotest /dev/null %{_localstatedir}/log/openqa || :
fi

if [ $1 -eq 1 ]; then
        echo "### copy and edit %{_sysconfdir}/apache2/vhosts.d/openqa.conf.template!"
        echo "### run sudo %{_datadir}/openqa/script/fetchneedles"

else
	if [ -d "%{_localstatedir}/lib/openqa/share/testresults" ]; then
           # remove the symlink
           rm "%{_localstatedir}/lib/openqa/testresults"
           mv "%{_localstatedir}/lib/openqa/share/testresults" "%{_localstatedir}/lib/openqa/"
        fi
fi

%service_add_post %{openqa_services}

%post worker
%tmpfiles_create %{_tmpfilesdir}/openqa.conf
%service_add_post %{openqa_worker_services}

%preun
%service_del_preun %{openqa_services}

%preun worker
%service_del_preun %{openqa_worker_services}

%postun
%service_del_postun %{openqa_services}
%restart_on_update boot.apparmor

%postun worker
%service_del_postun %{openqa_worker_services}

%post local-db
%service_add_post openqa-setup-db.service

%preun local-db
%service_del_preun openqa-setup-db.service

%postun local-db 
%service_del_postun openqa-setup-db.service

%files
%doc README.asciidoc
%{_sbindir}/rcopenqa-gru
%{_sbindir}/rcopenqa-scheduler
%{_sbindir}/rcopenqa-resource-allocator
%{_sbindir}/rcopenqa-websockets
%{_sbindir}/rcopenqa-webui
%dir %{_sysconfdir}/openqa
%config(noreplace) %attr(-,geekotest,root) %{_sysconfdir}/openqa/openqa.ini
%config(noreplace) %attr(-,geekotest,root) %{_sysconfdir}/openqa/database.ini
%dir %{_datadir}/openqa
%dir %{_datadir}/openqa/etc
%dir %{_datadir}/openqa%{_sysconfdir}/openqa
%{_datadir}/openqa%{_sysconfdir}/openqa/openqa.ini
%{_datadir}/openqa%{_sysconfdir}/openqa/database.ini
%config %{_sysconfdir}/logrotate.d
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.opensuse.openqa.conf
# apache vhost
%dir %{_sysconfdir}/apache2
%dir %{_sysconfdir}/apache2/vhosts.d
%config %{_sysconfdir}/apache2/vhosts.d/openqa.conf.template
%config %{_sysconfdir}/apache2/vhosts.d/openqa-common.inc
%config %{_sysconfdir}/apache2/vhosts.d/openqa-ssl.conf.template
# apparmor profile
%dir %{_sysconfdir}/apparmor.d
%config %{_sysconfdir}/apparmor.d/usr.share.openqa.script.openqa
# init
%dir %{_unitdir}
%{_unitdir}/openqa-webui.service
%{_unitdir}/openqa-gru.service
%{_unitdir}/openqa-scheduler.service
%{_unitdir}/openqa-resource-allocator.service
%{_unitdir}/openqa-websockets.service
# web libs
%dir %{_datadir}/openqa
%{_datadir}/openqa/templates
%{_datadir}/openqa/public
%{_datadir}/openqa/assets
%{_datadir}/openqa/dbicdh
%{_datadir}/openqa/script/check_dependencies
%{_datadir}/openqa/script/clean_needles
%{_datadir}/openqa/script/create_admin
%{_datadir}/openqa/script/fetchneedles
%{_datadir}/openqa/script/initdb
%{_datadir}/openqa/script/openqa
%{_datadir}/openqa/script/openqa-scheduler
%{_datadir}/openqa/script/openqa-resource-allocator
%{_datadir}/openqa/script/openqa-websockets
%{_datadir}/openqa/script/upgradedb
%{_datadir}/openqa/script/modify_needle
# TODO: define final user
%defattr(-,geekotest,root)
# attention: never package subdirectories owned by a user other
# than root as that opens a security hole!
%dir %{_localstatedir}/lib/openqa/db
%dir %{_localstatedir}/lib/openqa/images
%{_localstatedir}/lib/openqa/testresults
%dir %{_localstatedir}/lib/openqa/share/tests
%dir %{_localstatedir}/lib/openqa/share/factory
# iso hdd repo must be geekotest writable to enable *_URL and HDD upload functionality
%dir %{_localstatedir}/lib/openqa/share/factory/iso
%dir %{_localstatedir}/lib/openqa/share/factory/hdd
%dir %{_localstatedir}/lib/openqa/share/factory/repo
%dir %{_localstatedir}/lib/openqa/share/factory/other
%ghost %{_localstatedir}/lib/openqa/db/db.sqlite
%ghost %{_localstatedir}/log/openqa

%files common
%dir %{_datadir}/openqa
%{_datadir}/openqa/lib
%exclude %{_datadir}/openqa/lib/OpenQA/Client.pm
%dir %{_localstatedir}/lib/openqa
%ghost %dir %{_localstatedir}/lib/openqa/share/
%{_localstatedir}/lib/openqa/factory
%{_localstatedir}/lib/openqa/script
%{_localstatedir}/lib/openqa/tests

%files worker
%{_sbindir}/rcopenqa-slirpvde
%{_sbindir}/rcopenqa-vde_switch
%{_sbindir}/rcopenqa-worker
%config(noreplace) %{_sysconfdir}/openqa/workers.ini
%config(noreplace) %attr(0400,_openqa-worker,root) %{_sysconfdir}/openqa/client.conf
# apparmor profile
%dir %{_sysconfdir}/apparmor.d
%config %{_sysconfdir}/apparmor.d/usr.share.openqa.script.worker
# init
%dir %{_unitdir}
%{_libexecdir}/systemd/system-generators
%{_unitdir}/openqa-worker.target
%{_unitdir}/openqa-worker@.service
%{_unitdir}/openqa-worker-no-cleanup@.service
%{_unitdir}/openqa-slirpvde.service
%{_unitdir}/openqa-vde_switch.service
%{_tmpfilesdir}/openqa.conf
%ghost %dir %{_rundir}/openqa
# worker libs
%dir %{_datadir}/openqa
%dir %{_datadir}/openqa/script
%{_datadir}/openqa/script/worker
%dir %{_localstatedir}/lib/openqa/pool
%defattr(-,_openqa-worker,root)
%dir %{_localstatedir}/lib/openqa/cache
# own one pool - to create the others is task of the admin
%dir %{_localstatedir}/lib/openqa/pool/1

%files client
%dir %{_datadir}/openqa
%dir %{_datadir}/openqa/script
%{_datadir}/openqa/script/client
%{_datadir}/openqa/script/clone_job.pl
%{_datadir}/openqa/script/dump_templates
%{_datadir}/openqa/script/load_templates
%dir %{_datadir}/openqa/lib
%{_datadir}/openqa/lib/OpenQA/Client.pm
%{_bindir}/openqa-client
%{_bindir}/openqa-clone-job
%{_bindir}/openqa-dump-templates
%{_bindir}/openqa-load-templates

%files doc
%doc docs/*

%files local-db
%{_unitdir}/openqa-setup-db.service

%changelog
* Sat May  5 2018 coolo@suse.com
- Update to version 4.5.1525548058.3f6bb61a:
  * Avoid appending multiple runs with --nocleanup (#1644)
  * Limit number of tasks for limit_assets and limit_results_and_logs GRU tasks
  * Add test for GRU enqueue limit option
  * Update apparmor profile for worker (#1645)
  * GRU: Add support to limit enqueuing by task
  * Update unit tests for TAP parser
  * Mark test suite as failed if test steps have failed
  * Add information about openQA internal results
  * Update TAP format documentation
  * Remove dots from filename
  * Ensure that the details description is set
  * Use a single result to contain all the test steps
  * Update changes to TAP format
  * Temporary version of the parser for TAP still failing
  * Log a warning when step data is not found
  * Allow LTP parser to load files that contain special characters
  * Replace extra dots in the filenames (#1642)
  * Increase the required coverage to 88.8
  * Do not fail a pull request if there are unexpected changes
  * Use same width for each colored dep status span
  * Show parent and child deps on job page in nice tbl
  * Enhance unit tests for GRU TTL
  * Set 2 days of ttl for limit_assets and limit_results_and_logs when posting isos
  * Add unit test for GRU task TTL
  * GRU: Add TTL for Minion jobs
  * Use a smaller font for the 'ago time' to fix rendering (#1635)
  * Prefetch comment counts for /tests
  * Update bootstrap to 4.1.1 and fontawesome to 5.0.10
  * Do not load full application to generate assetpack data (#1628)
  * Improve the duplication tests (#1627)
  * Hide categories when filtering test details
  * Ensure needles directory exists in 18-tests-details.t
  * Require 'Selenium::Remote::WDKeys' in CPAN file
  * Add test for filtering test details
  * Allow filtering test details
* Tue Apr 24 2018 coolo@suse.com
- Update to version 4.5.1524586233.92db89bc:
  * Add unzip-plain to AppArmor profile (#1629)
  * Use current SUSE Logo (#1626)
  * Avoid skipping dependencies when cloning jobs. (#1623)
  * Improve some details in t/ui/18-tests-details.t
  * Randomize GET /tests/99946#step/yast2_lan/1
  * Use usual prove flags on Travis as well
  * Hide failed modules on overview table for small screens
  * Fix positioning tooltips with Bootstrap 4 on overview page
  * Add Minion Link to navbar and move under admin
  * GRU: delete gru and deps on failure
  * Fix spacing of 'Build + Bars' rows on dashboard
  * Adjust padding and media break points for dashboard
  * Use exact same colors for cards/panels as before
  * Add unit test for job custom_module
  * Display GRU failure as job test module in openQA
  * Fix dropdown menus in fullscreen mode
  * Use full width in full screen mode
  * Make the gru service to be restarted on-failure
  * OpenQA::Task::* Die on fatal errors
  * Catch all tasks output also in case of error
  * Mark the jobs associated to the gru task incomplete in case of gru task failure
  * Adapt to new Minion::Job API introduced in Minion 9.0
  * Remove unused Data::Dumper import
  * Use Minion::Command::minion::job to get jobs list
  * Enable the Minion Admin interface under /minion
  * GRU/Minion: Take account of failures
  * Use gru enqueue in controllers and keep relation with minion jobs
  * Adapt test and fix leak of memory
  * Gru: get dsn from DBI for Minion
  * Move GRU tasks to Minion
* Fri Apr 20 2018 edigiacinto@suse.com
- Require Minion >= 9.02
* Thu Apr 19 2018 coolo@suse.com
- Update to version 4.5.1524056562.74e334c1:
  * Close candidate menu after selection
  * Fix positioning of dropdown icon under Firefox
  * Fix handling multi-tag tests
  * Adjust UI tests to handle new candidates selection
  * Implement full diff
  * Allow to show just the screenshot again
  * Add shortcuts to custom combo box
  * Make style for result preview part of openqa.scss
  * Use customized bootstrap dropdown instead of combo box
  * Workaround issue when clicking menu item in 21-admin-needles.t
  * Port card in overview correctly to Bootstrap 4
  * Use same link color as before
  * Make badges look like before
  * Adjust colors
  * Fix paging of tables for running and scheduled jobs
  * Remove symlinks for Glyphicon fonts
  * Fix UI and fullstack test after Bootstrap 4 migration
  * Adjust media breakpoints
  * Fix grammar in tour
  * Upgrade tour to Bootstrap 4
  * Restructure stylesheets
  * Fix live-view and other small issues under Bootstrap 4
  * Make it look more like before under Bootstrap 4
  * Fix permanentely moved links on dashboard
  * Fix overall appearance with Boostrap 4
  * Fix filter panel on the main page
  * Patch bootstrap theme to be a little more like it was before
  * Remove hidden class
  * Port the navbar to bootstrap 4
  * Start to migrate to bootstrap 4
* Fri Apr 13 2018 coolo@suse.com
- Update to version 4.5.1523608608.fca0aa46:
  * Enforce sorting the results returned by the sql query to use in is_deeply (#1621)
  * Remove dead code in Worker/Jobs.pm
  * Update current test module details when cancelling running job
  * Prevent failures in worker reset_state() (#1618)
  * Group candidate needles by tag (#1606)
  * Test image selection of needle editor (#1617)
  * Fix 'Take image from' selection in needle editor (#1616)
  * Refactor needle editor code
  * Fix showing needle editor when no tags present
  * isotovideo: wrap log_ calls with eval
  * Require latest RWP
  * Start isotovideo inside a container using cgroups
  * Checks if failure status file exists before trying to slurp it
  * tests: cover case when one of the cluster jobs already running
  * Consider running jobs in filter_jobs
  * Fix fullstack test in case /usr/bin/isotovideo is present
  * Limit showing new needles to the 5 most recent ones
  * Use 'new' prefix when showing new needles
  * Add documentation about showing new needles in editor
  * Improve tests for needle editor
  * Show errors/warnings/info in needle editor with consistent margin
  * Show added/updated needles in editor
  * Add database entry for needles when saving via editor
  * Simplify save_needle_ajax code
  * Extend needle table with tags and timestamps
  * Capture serial patterns documentation
  * Don't show configure button for untracked assets
  * Fix mojo not handling max_size_limit when is a transaction
  * Allow optional overwrite of the productlog request depth with a query parameter (#1601)
  * Enable JSON representation of the test overview (#1600)
  * Add asset size limit option
  * Return reference for test result file lists
  * Make OpenQA::Client::Archive property of OpenQA::Client
  * Remove chdir that caused errors when downloading test files
  * Add file _download_file_at method for logs and uploaded logs
  * Move progress monitor code to a separate fuction
  * Ensure that uploaded test logs can be downloaded
  * Add first version of OpenQA::Client::Archive
  * Move test_uploadlog_list and test_resultfile_list to the model
* Fri Apr 13 2018 edigiacinto@suse.com
- Use Minion for GRU tasks, this requires Minion and Mojo::Pg as dependency
* Thu Apr 12 2018 marius.kittler@suse.com
- Fix handling UTF-8 when executing make install
* Thu Apr 12 2018 marius.kittler@suse.com
- Fix handling UTF-8 in update-cache.sh
* Sat Mar 10 2018 coolo@suse.com
- Update to version 4.5.1520515419.c3df6f91:
  * Update the chromedriver url from 2.33 to 2.36
  * Allow saving needles for OS with dots in the version
  * docs: Clarify some serial terminal terminology and other elaboration (#1596)
  * Do not reset the api version just because the worker is offline
  * Fix scheduler comment - now default MAX_JOB_ALLOCATION is 80 (#1595)
  * Always retry until chunk is uploaded and retrials exhausted (#1594)
  * Refactor and add error test
  * PARALLEL_CLUSTER is no more
  * Adapt scheduler_full test
  * Avoid to re-consider the jobs that are being allocating in a round
  * Do not take account of spaces in PARALLEL_WITH
  * Exclude allocating jobs from prefer_parallel cut
  * Consider allocating only when we have them
  * Bump MAX_JOB_ALLOCATION default to 80
  * Exclude allocated when blocking dependencies
  * Consider the jobs allocated during the round as running in prefer_parallel
  * Prevent cluster tests to be allocated if their group is not allocated
* Tue Mar  6 2018 coolo@suse.com
- Update to version 4.5.1520100590.2279151e:
  * Fix sort order of the review comments (#1593)
  * Expand the serial terminal console documentation (#1586)
  * Emit openqa_job_create events when an ISO is posted (#1584)
  * Replace die for 500 code and move global constants to OpenQA::Constants
  * Avoid circular dependencies when running the tests.
  * All the available free workers need to have the same websocket interface version
  * Move the interface verification to the worker ack
* Sat Mar  3 2018 coolo@suse.com
- Update to version 4.5.1519929327.f726adcc:
  * Enable wrapping cells in overview table (#1591)
  * Perltidy
  * Protect during collected unsubscription
  * Prevent to determine job status from collected event when timout expires
  * Remove check backend timer
  * Fix check_backend detection
  * cpanfile: require at least Mojo::IOLoop::ReadWriteProcess 0.19
  * Adapt jobs tests - we are not dying anymore
  * Don't fear the (sub)reaper
  * Add AMQP doc
  * Lock tidy version
  * Make prove verbose
* Tue Feb 20 2018 coolo@suse.com
- Update to version 4.5.1519128406.810fb68b:
  * Show correct port for created job (#1578)
  * Use rwp also to call rsync (#1585)
  * Force a restart when the children or grand-children processes die
  * OpenQA::Parser::Format::JUnit mark testsuite failed if one of testcases fails
  * Replace the exec call with ReadWriteProcess module
  * Add use Mojo::DOM in JUnit and XUnit Parser (#1580)
  * Use the generated Mojo::URL as Client base_url
  * Add get_piece() in OpenQA::File to ease writing of downloader class
  * Add test for OpenQA::Files's prepare()
  * Make integration tests of uploader with fixed chunk size
  * Fire events inside subprocess before and after chunk processing.
  * Move uri checks inside common function in OpenQA::Client::Handler and guard from not configured scheme in host
  * Add test to check if retrials numbers are matching
  * Use subprocess for potential loop blocks
  * Adapt workers to error handling
  * Add tests for OpenQA::Client::Upload retrials on failures, and events propagation
  * Emit errors on OpenQA::Client::Upload
  * Swap multi-chunk uploader in worker with OpenQA::Client
  * Make OpenQA::Handlers EventEmitter(s)
  * Split OpenQA::Client
  * Wipe out content of written chunk, try only weak check and back to Storable
  * Do not always perform total cksum
  * Drop Mojo force to File asset, display stats of uploaded chunks
  * Write as we receive in a temp file
  * Avoid to relay too much on the serializer
  * Use C backend to read whole file when computing total cksum
  * Enhance error detection
  * Allow to chunks to dynamically grow and shrink
  * Make total checksum verification run faster
  * Let specify chunk size in config file, and default to 1000000 bytes
  * Also add API endpoint to inform of upload status, adapt tests
  * Do not make split() to load the file
  * Pass asset option in multichunk upload
  * Create empty file before writing it if doesn't exist
  * Try to swap current uploader with multi-chunked one for assets
  * Add spurt to OpenQA::Files
  * Add write_verify_chunks() and write_chunks to OpenQA::Files
  * Add methods to verify against chunks, also add test when joining/verifying in-place
  * Add serialize/deserialize also to single result of parser
  * Add OpenQA::File, wraps Mojo::File and adds seek capabilities
  * Add worker version check on the server. (#1552)
  * Add basic test for OpenQA::WebAPI::Description
  * Add POD documentation to Controller/API/V1 packages
  * Test 27-errorpages.t with a predefined API desc
  * Replace Pod::Tree for Pod::POM in WebAPI::Description
  * Add POD documentation to Controller/API/V1 packages
  * Move API description methods to its own package
  * Add POD documentation to Controller/API/V1 packages
  * WebAPI: Add API description from Controller's POD
* Sat Feb 10 2018 coolo@suse.com
- Update to version 4.5.1518003872.3977d2f5:
  * Run perltidy again (#1577)
  * Fix perltidy complaints (#1576)
  * Give 404 rather than 500 on invalid asset route (#1575)
* Tue Feb  6 2018 coolo@suse.com
- Update to version 4.5.1517920216.2250682a:
  * Take latest version of Selenium::Remote::Driver (#1570)
  * Big rework of the GRU limit_asset task (#1569)
  * Fix broken links in openQA documents
  * Update Installing.asciidoc
  * Add pager for comments on group overview (#1561)
  * Add help box for group filter
  * Fix testsuite descriptions if default config not present (#1554)
  * Test subgroup filter and form
  * Allow to expand nested groups by default
  * Add filter for subgroups
  * Check qemu pid before starting job (#1565)
  * Require < 1.21 of Selenium::Remote::Driver
  * Downgrading selenium drivers during test phase
* Tue Jan 30 2018 coolo@suse.com
- add fonts for chromium test suite - and remove currently broken
  tests (https://progress.opensuse.org/issues/19652)
* Tue Jan 23 2018 coolo@suse.com
- Update to version 4.5.1516716144.98db9c99:
  * Improve error handling in group overview (#1562)
  * Do not remove forwarded-for=https headers (#1558)
* Sat Jan 13 2018 coolo@suse.com
- Update to version 4.5.1515767133.56cd6ee5:
  * Support nested OpenQA::Parser objects
  * If no parser format is supplied, return a OpenQA::Parser::Format::Base object
  * Add POD documentation for OpenQA::Parser::Result::OpenQA
  * Add documentation for OpenQA::Parser::Results and move search() in proper class
  * Move search_in_details() in a new class that inherits from OpenQA::Parser::Results as it is openQA specific
  * Add documentation of OpenQA::Parser::Result
  * Move methods and attributes from Parser to Base format
  * Simplify spec format definition and move common displayed fields to openqa specific result classes
  * Drop support for creating collections with package global variable (useless now)
  * Make possible to upload in all the supported format and add tests for it
  * Add other tests, bring back coverage and fix wrong Node val() assigment
  * Return a OpenQA::Parser::Result::Node object when getting unstructured data from result
  * Make parser now really recurive, add also support for nested data structure with unit test
  * Make LTP parser tests output compliant to openQA tests results
  * Run parser test in parallel
  * Add possibility to store / serialize file content too within the parsed result
  * Add test to check DB consistency with parser extracted results
  * Move format specifications to separated namespace
  * Add XUnit tests
  * Add basic XUnit parser and schema
  * Clean LTP and include schema inside parser file
  * Add support for nested Results collections (required for XUnit)
  * Use functional interface in exposed api
  * Make collections serializable for unstructured data
  * Add accessor for unstructured data
  * Ask to include result only if the specific parser can
  * Move include_result option to specific parser that needs it
  * Provide also functional interface
  * Serialize single Results object as seen by to_hash() and add tests
  * Add tests when parser errors
  * Support hashifications of unknown objects
  * Add unstructured data test
  * Add reset method to parser, add and cleanup tests
  * Make serializing possible for collections with different OpenQA::Parser::Results objects
  * Add possibility to export/import the Parser to JSON, add also tests
  * Add serialization tests for junit spec
  * Tidy OpenQA::Parser::Result
  * Hide name field in JSON encoding of OpenQA result - but keep serializing it
  * Add example of new format specification for LTP
  * Simplify LTP spec definition even more
  * Get hash representation automatically of attributes if they can be rendered as hash
  * Add backword support for v2 format and add unit tests
  * Rename subtest to avoid Perl 5.18 complaints
  * Refactor write of parser result data
  * Add optional extra list that can be filled by type spec parser
  * LTP specification: Environment is optional inside result in new format
  * Add support to serialize/deserialized nested data structure
  * Add serialization capabilities to parser, and add tests
  * As classes are representing merely what's the json content, include them in the LTP module file
  * Add test data example for LTP results format
  * Add support for LTP specification in OpenQA::Parser
  * Generalize parser results, and subclass to specific implementations
  * Adapt parser tests, since now default value for script is 'unk'
  * Generate test module result from parsable extra_tests
  * Parser: return unk for test script if does not exist
  * Add search between parsed tests, link results and tests
  * Draft for JUnit parser
  * Prevent worker status selection to sort (#1555)
  * Unify code for scheduled/running table and fix sorting (#1556)
  * Remove leftovers in t/api/02-assets.t (#1557)
* Tue Jan  9 2018 coolo@suse.com
- Update to version 4.5.1515509269.fa07a084:
  * Remove assets from disk when deleting database entry (#1553)
* Thu Dec 21 2017 coolo@suse.com
- Update to version 4.5.1513750232.be133588:
  * Add basic setup of multi-machine worker (#1544)
  * Allow deleting assets via web UI (#1551)
  * Deal properly with environment variables that can change logging (#1537)
  * Fix deletion of jobs referenced as last use of asset (#1549)
  * Show assets by job group
  * selenium test: Allow configuring mojo port
  * Split asset tables in used and untracked assets
  * Refactor data size rendering in JS and reduce precision
  * Set App mode in WebSocket server (#1548)
  * Fix repos gone too early: assign REPO_10 to jobs as well (#1547)
  * Retidy - Perl::Tidy 20171214 has different formatting (#1546)
  * Update installation steps for postgresql (#1538)
  * branding: openSUSE: Add Kubic (#1539)
  * Change the logs timestamp to ISO8601 (#1542)
  * Add documentation for postgresql migration (#1530)
  * Fully fix asset caching without test caching (POO #29208)
  * Fix job group update issue (#1533)
  * Hide worker properties if no login (#1534)
  * Switch to fontawesome 5 (#1531)
  * `limit_assets`: remove asset that breaks limit, not next one (#1536)
  * Remove all assets from DB that are gone (#1535)
  * Allow to query live data from api, adapt tests
  * Display additional information in the worker's table
  * Add panel and popover to show job detail
  * Make searchable field and fix DataTable loading
  * Add openqa-setup-db service that will create postgresql database (#1528)
  * Retrieve worker stats data
  * Do not query by default websocket server to display worker informations
  * Fix tests to expect new columns
  * Show size of assets exclusively kept by a group
  * Accumulate size of assets exclusively kept by a group
  * Document fast initialization of local tests (#1527)
  * Add column to groups with size of exclusively used assets
  * Also store if the asset is fixed in the DB
  * limit_assets: Use DBD::Pg directly for querying job asset
  * Check all columns in test for asset table
  * Show last use of asset in assets table
  * Ignore chromedriver logs
  * Show asset size
  * Write info about assets kept during cleanup to db
  * Improve comments in limit_assets
  * Fix PRJDIR error
  * Add support for colons on worker class
  * Add WORKER_CLASS to job_list filter
  * Fix caching of assets without caching of tests (#1521)
  * Accept a lower coverage - we removed code
  * Move worker log test to 24-worker.t
  * Schema.pm: Remove unused functions (increase coverage)
  * Remove SQL files for SQlite and for 2016
  * Have our services require postgresql server to be up
  * Adopt generate-packaged-asset to use postgresql
  * Import log_error in OpenQA::IPC
  * Test: increment unstable_worker ticks and wait for each one to be ready
  * Remove more traces of Sqlite support
  * Provide t/test_postgresql to setup a temporary postgresql
  * Fix more test cases
  * Prepare a proper DB for the scheduler full test
  * Fix t/ui/22-job_group_order.t by providing sort_order in fixtures
  * t/ui/13-admin.t: Postgresql sorts RAID at the end
  * Sort table settings by key to have reliable tests
  * t/api/02-iso.t: Do not rely on hardcoded job number
  * Give WebSockets server its assets
  * Sort the previous jobs in worker table by ids
  * Skip all tests requiring a database
  * Test fixtures: restart the postgresql sequence
  * Fix t/17-build_tagging.t not to depend on Sqlite specifics
  * ui/04-api_keys.t: Don't rely on ids in fixtures
  * 14-grutasks: don't rely on DB sort order
  * Drop sqlite3 support
  * branding: Update SLE staging links (#1523)
  * Use log_info for worker activities (#1519)
  * branding: openSUSE: Add caasp (different bugzilla naming variant) (#1522)
  * Tidy the sources
  * Do not cast to int worker_status timer
  * Propagate error on IPC dispatch call
  * Use WORKERS_CHECKER_THRESHOLD to detect dead workers as well
  * Remove printing to debug the result of safe_call
  * Reduce OpenQA tests verbosity
  * limit_assets: don't wipe assets for PENDING jobs (#1518)
  * Allow same group name within different parent groups (#1507)
  * Apply log level correctly (#1516)
  * Check if job is valid before starting working on it.
  * Upload workers log to the webUI (#1502)
  * Only test basic tests on perl 5.26 (#1512)
  * Remove IDs from fixtures if they are in sequence (#1513)
  * Move the $shared_dir to setup_share_dir
  * Print project directory upon worker's init failure
  * Fix documentation generation script
  * Avoid warnings during test runs (#1511)
* Wed Dec  6 2017 coolo@suse.com
- Add local-db subpackage to create local postgresql database for
  ease of use
* Tue Nov 28 2017 coolo@suse.com
- Update to version 4.5.1511814842.53907890:
  * Make barrier option to automatically destroy the barrier if jobs belonging to it fails (#1498)
  * Improve web editor (#1510)
  * Remove outdated imports of JSON module (#1509)
  * Use Cpanel::JSON::XS in step/edit.html (#1508)
* Mon Nov 27 2017 coolo@suse.com
- Update to version 4.5.1511709996.0670f622:
  * Use OPENQA_TEST_IPC for 12-admin-workers.t (#1506)
  * Poll status less often not to stress the server
  * Adapt coverage threshold
  * Mark workers dead when they disconnect from WS
  * Make full stack test more robust by adding more assertions
  * /tests/overview: Change sorting to show all machine variants together (#1489)
  * Use Cpanel::JSON::XS directly to avoid overwrite mess
  * Extend apparmor permissions for /usr/share/openqa/lib/** (#1504)
  * Test multiple perl versions in travis CI
  * Ignore specific 404 errors in the javascript console
  * Click away the feature tour in full stack
  * Make 21-admin-needles more robust
  * Clean VHD and VHDX images in cache
  * Treat VHD and VHDX images as HDD assets
  * Replace logrotate config with what we use in production (#1500)
  * Fix function names in ui tests
  * Rename PhantomTest to SeleniumTest
  * Remove support/work arounds for phantomjs
  * Use headless chrome instead of phantomjs
  * Use proper name and directory for PhantomTest
  * Update Cache documentation (#1495)
  * Make path of changelog configurable via config file
  * Add changelog for web UI
  * Avoid creating useless commits (#1497)
  * Add _ONLY_OBSOLETE_SAME_BUILD, _NOOBSOLETEBUILD -> _NO_OBSOLETE
  * Multiple loggings channels
  * Log Uniformization
  * Make sure /tests/overview shows test suite descriptions for all machines
  * Display job name on dependencies list
  * Worker: use population as scale_factor
  * Add websocket server test to cover errors when updating worker seen status and population update
  * Make threshold for worker_checker a constant, and tight the bond between the status timer and the timer for checking inactive workers
  * Use in_range from OpenQA::Utils in scheduler-full test
  * Best effort to let know worker population of different WebUIs
  * Move worker configuration reading to Worker::Common, making it easier to test and slim down the startup script
  * Remove already superseded default inactivity timeout from script/openqa-websockets
  * Remove keepalive message and introduce dynamic slot allocation for worker_status timer
* Fri Nov 24 2017 coolo@suse.com
- adapt build dependencies to Cpanel::JSON::XS
* Wed Nov 22 2017 coolo@suse.com
- replace phantomjs with chromium/chromedriver
* Sat Oct 28 2017 rd-ops-cm@suse.de
- Update to version 4.5.1509097496.8b8e8e20:
  * Prevent use of job_module_stats when showing jobs of worker
  * Fix sorting in table for previous jobs of worker
  * Remove all remaining uses of job_module_stats
  * Fix accessing job module stat 'unk'
  * Worker: Wrap asset_lookup() query in eval/if
  * Add API description for worker route
  * docs: Prevent parsing of '#' as markup
  * Allow admins to fetch the worker status by json
  * Fix name of the SUSE company
  * Prevent showing duplicated bugrefs twice
  * Fixing the package to build with newer assetpack (#1485)
  * Mention repos for Leap 42.3
* Thu Oct 26 2017 rd-ops-cm@suse.de
- Update to version 4.5.1508961373.6d2e83a0:
  * Scheduler: Add option to deal with slow workers that could be detected as dead.
  * Scheduler: Handle stop/restart cleanly
  * Respect log level configuration even when no log file is set (#1413)
  * More prominent color for closed bug references, old ones for open bugs (#1412)
  * Scheduler: implement retrials before declaring a job not accepted by a worker
  * Scheduler: add option to wakeup when we receive new jobs
  * Adjust full-stack tests scheduler default values
  * API/Worker: Get updates from job that match the worker id
  * Revert "Permit a dropped test coverage for now" as we are covered now
  * Worker: send worker_id when updating setup status
  * Job: Return error messages when worker doesn't send id
  * docs: Move label and bugrefs doc from wiki
  * docs: Add description of closed issue visualization
  * Use OPENQA_TEST_IPC in more tests due to scheduler changes
  * Scheduler: add code comments, refactorize and simplify code
  * Include '.' in INC for 24-feature-tour.t (#1420)
  * Scheduler: Remove EXPBACKOFF option and default to binary
  * Scheduler: Remove shuffle option. Is new default now, if we don't shuffle free workers we might go into starvation since they can keep failing
  * Scheduler: schedule() now returns allocated jobs and failures
  * Websockets: distinct error while dispatching job over ws
  * Improve error if a worker cannot connect to a WebSocket (#1416)
  * Conflict no-cleanup worker with normal worker (#1417)
  * Scheduler: Add basic unit testing
  * Scheduler: remove retrials and workers cache
  * Scheduler: use another state for jobs that have been assigned but are not yet in running status
  * Worker/Websockets: Make worker send status messages, and websockets reaping jobs that are not matching states
  * Websockets: print details of messages received from unknown workers
  * Websockets: remove (now) misleading debug message
  * Worker: do not die in the loop when current_host is not set
  * Scheduler test: simulate unstable workers
  * Workers: collect error if we fail dispatching commands to websocket dbus service
  * Scheduler/WebSockets/Worker: update job state to running from worker responses
  * Scheduler: now job allocation checks are not needed anymore inside scheduler
  * WebSockets: use set_running when updating job status (#1426)
  * Add support for custom links in footer
  * Fix staging link for CaaSP
  * Worker: increase keepalive timer
  * Seperate footer links from footer legal part
  * Add 'report Bug' for OpenQA product
  * Scheduler: sleep when we have nothing to do
  * Adapt scheduler tests to new sleep mode
  * WebSockets: reset to schedule state if we detect stale assigned jobs
  * Websockets: set default appname - which is used in error templates
  * Websocket: wrap database transactions in try catch so we can debug dbus service errors
  * Create base for fullscreen mode on group overview site
  * Include just show latest comment feature
  * Add disable comments feature in group overview
  * Add fullscreen to group overview and rewind comments part
  * Fix uninitialized value error and typos
  * Add autorefresh for builds and comments in group overview
  * Make auto refresh rate adjustable
  * Fix sporadic problem of systemd service start (poo#21004) (#1430)
  * Add description part for api routes at not_found page
  * Add a quick tour to openQA
  * Enable feature tour by changing database entry
  * Adjust ui test
  * Replace old DEPENDENCIES.txt references to cpanfile (#1423)
  * Templates: improve error handling in running_table (#1427)
  * Utils: Flush log output when we don't use Mojo::Log
  * WebSockets: finish connection when we don't have the worker registered
  * Workers: print debug output when connection is closed
  * WebSockets: enable required plugin on setup
  * Add tests for WebSocket disconnection handling
  * Add missing figure for closed ticket labels
  * Prevent use of job_module_stats when showing jobs of worker
  * Fix sorting in table for previous jobs of worker
  * Remove all remaining uses of job_module_stats
  * Fix accessing job module stat 'unk'
  * Treat ASSIGNED state as in execution
  * Subscribe start_job/stop_job events before we call send on websocket connection
  * Worker: reset internal state if we fail contacting the WebUI
  * Worker: Do not cleanup if pooldir is not set
  * Add support for multiple distri/version/group on /tests/overview
  * Websocket: Do not kill connections due to inactivity (meant mostly for browsers)
  * Dereference hashrefs before using 'keys'
  * Check whether description available before printing it
  * Cover the websocket server to avoid uncovered changes with CI builds
  * Include all relevant distros when linking overview
  * Use Mojo::Log for logging worker's output
  * Refactor worker status messages
  * Cover main OpenQA.pm, which was left with low coverage
  * Changes the log level to debug if --debug or --verbose is applied. Default is info level.
  * Fix use of undefined $email by using default icon instead (#1444)
  * Sync needles when caching is enabled
  * Use cache_tests from isotovideo engine
  * Better reflect job execution through states
  * Replace tabs with spaces and fix indentation.
  * Ensure CSS classes are used for Datatables
  * Add setup state to be polled and tidy up
  * Test 404 error page
  * Ensure use of symlinked applications for clone_job/dump_templates/load_templates
  * Trim less text in overview tables by using CSS instead of custom code
  * Disable live log/terminal by default
  * Untie live stream from live log
  * Make details the default tab also for running jobs
  * Ensure streams for live view are only consumed when tab is active
  * Allow info/debug messages in javascript_console_is_empty
  * Switch to live view by default in full stack test
  * Move read_test_modules to OpenQA::Utils
  * Add support for getting test results as json
  * Fix missing openQA::Client import introduced in 7c91a962
  * Improve documentation for contributors
  * Log IPC errors
  * make Makefile non-bash environment friendly (#1465)
  * Add log function log_fatal
  * Allow filtering by result on 'All tests' page
  * Add query param for filtering 'All tests' table by result
  * Adapt bugzilla link to new SLE15 installer (#1466)
  * Fix filtering by result on 'All tests' page for some results
  * Test enabling result filter on 'All Tests' page via query
  * Fix regression introduced in https://github.com/os-autoinst/openQA/pull/1460
  * Ignore .pc directory for perltidy (#1472)
  * Fix missing log_warning import on IPC.pm (#1473)
  * Cherry pick perltidy fixes from @henrich (#1475)
  * docs: Add hint about performance impact of VM snapshots (#1474)
  * Create ResourceAllocator DBus service
  * Split fullstack tests in different build matrix
  * Create exists_worker in OpenQA::Utils
  * Use schema from ResourceAllocator instance, refactor to use exists_worker
  * Adjust scheduler full tests after the split
  * OpenQA::ServerStartup: set also appropriate handle when setting up logging, since now FakeApp has STDOUT as default handle
  * Add safe_call to OpenQA::Utils
  * Switching to safe_call in ResourceAllocator
  * Make job update take into account of ASSIGNED and SETUP state
  * Worker: Reset state also when we loose current_host (due to failure contacting webserver)
  * Return 0 by default on worker's try_lock_asset()
  * Worker: Wrap asset_lookup() query in eval/if
  * Make heartbeat timeout for rabbitmq configurable (#1479)
  * Add API description for worker route
  * docs: Prevent parsing of '#' as markup
  * Allow admins to fetch the worker status by json
  * Fix name of the SUSE company
  * Prevent showing duplicated bugrefs twice
* Fri Aug 18 2017 okurz@suse.com
- Provide clone-job, dump-templates, load-templates as symlinks in bin-path
* Wed Aug  2 2017 rd-ops-cm@suse.de
- Update to version 4.5.1501694730.25c355a8:
  * OpenQA::WebAPI::Controller::API::V1::Job: catch errors and return no jobs when we fail to contact dbus
  * Schedule jobs without polling
  * Make workers only accept one job from one webui - also check if we dispatched the job correctly to the worker
  * Update worker seen status from ws keepalives if thought dead
  * Set to running just when we are sure the job got dispatched to the worker
  * Improve error handling when we fail resetting scheduling state
  * Do not use in the workers next_tick anymore when accepting the job
  * Fix the keep alive timer handling in worker
  * We need more timers to be host specific
  * Scheduler: Be more strict with job states
  * Apache: SetEnv proxy-nokeepalive 1
  * Permit a dropped test coverage for now
  * Scheduler: further optimizations and refinements
  * Get rid of notify_workers, and from the signal that was associated to it in the dbus scheduler service
  * Remove job grab from the API
  * Fix bugzilla links for CaaSP (#1395)
* Mon Jul 31 2017 rd-ops-cm@suse.de
- Update to version 4.4.1501432550.4c72a17b:
  * Some more permissions required for power8 worker (#1405)
  * schema: Add job module statistics to jobs table
  * Use job module stats from jobs table in 'All Tests'
  * Add . to INC for tests that use local modules (perl 5.26 doesn't) (#1406)
  * Update job module stats when module inserted/updated
  * Fix typo in networking documentation (#1407)
  * Add the job module statistics to the migration code (#1409)
  * SLE 'LeanOS' corresponds to 'Server' on bugzilla.suse.com (#1393)
  * Dynamic feature infos for users (#1388)
* Sun Jul 30 2017 rd-ops-cm@suse.de
- Update to version 4.4.1499449966.bd9ee915:
  * Replace die with log_error
  * Avoid edge case of asset sizes being incorrect.
  * Cache: resolve to current host when host URL cannot be resolved (#1352)
  * job templates: Fix removing options when finalizing row
  * job templates: Fix check for test selection when finalizing
  * job templates: Improve coding style in post
  * Fix bullet points in dashboard (#1356)
  * Provide a default (0) to max_rss_limit so that the config actually works (#1358)
  * Cache: Make each log message uniquely identifiable
  * Allow plugins to load specific configurations
  * Remove auth_config from OpenQA::WebAPI::Auth::*
  * Add fullscreen base into project
  * Add form entry for fullscreen view
  * Fix navbar to not hide if dropdown selected
  * Change help popover description in filtersection
  * Correct main controller and index page
  * Add error message for missing webserver
  * Also recognize kde bugrefs in Utils.pm (#1366)
  * Add link to CaaSP staging (#1360)
  * Also recognize fdo bugrefs in Utils.pm (#1367)
  * Database change for bug status
  * Improve assets log messages (#1365)
  * Documentation for GRE (#1369)
  * Extend sorting by time to parent group overview (#1362)
  * Add workaround for PhantomJS in needle edit test
  * Fix typo workround -> workaround
  * Prevent bugref_to_href replacement at end of title (#1372)
  * Refactor rendering response for server-side DataTable
  * Refactor server-side code for audit log
  * Refactor server-side code for previous jobs of worker
  * Test takeover of exclude areas in needle editor
  * Fix wrong HTML, input must not contain text
  * Show exclude areas in needle diff
  * Show exclude areas in needle editor always
  * Document areas
  * correct typo (#1379)
  * Enable INTEGRATION_TESTS (#1384)
  * Retrigger download retry for incomplete downloads
  * Fix perl structure printed in the logs
  * Check when asset has been removed by hand
  * Changing from using pure perl to Mojo::Asset::File
  * Allow the cache to use a configurable sleep time
  * Unlock the asset before the next download retry
  * Add unit test for cache
  * Add 25-cache.t to testrules.yml
  * Set sleep_time to 5 again
  * Remove unnecesary code from cache tests
  * Refactor server handling to avoid race conditions
  * Improve handling of logs and directories
  * Improve cache tests
  * Improve server_start and port handling
  * Remove unnecesary calls to Mojo::Asset::File
  * Fix test directory to share/tests (#1383)
  * Sort the failed modules on their timestamp not by their name (#1378)
  * Add test for "Server unavailable"
  * Inform user when OpenID login fails with no message from OpenID provider (#1380)
  * Increase the grace timeout to have uploads finish (#1385)
  * Notify the workers only when there are no errors
  * Create jobs from settings within a transaction
  * Increase information in logs if a wrong secret is used (#1374)
  * Avoid OpenID login to clutter log files (#1386)
* Tue Jun 20 2017 okurz@suse.com
- Exclude not supported and not building i586 in spec file rather than project
  config
- Use internal macro for %%setup
- Cleanup description and doc section
* Wed Jun  7 2017 coolo@suse.com
- disable tests on tumbleweed as they hang - need to debug this
  regression first
* Thu Jun  1 2017 rd-ops-cm@suse.de
- Update to version 4.4.1496302635.5e9b3f9:
  * Replace die with log_error
  * Avoid edge case of asset sizes being incorrect.
  * Cache: resolve to current host when host URL cannot be resolved (#1352)
  * job templates: Fix removing options when finalizing row
  * job templates: Fix check for test selection when finalizing
  * job templates: Improve coding style in post
  * Fix bullet points in dashboard (#1356)
  * Provide a default (0) to max_rss_limit so that the config actually works (#1358)
  * Cache: Make each log message uniquely identifiable
* Tue May 30 2017 rd-ops-cm@suse.de
- Update to version 4.4.1496150882.49e14ecd:
  * Avoid OpenQA::IPC::ipc being called premetaure (#1185)
  * Add $prjdir prefix for relative filenames in Needles
  * Add option to change $prjdir on the fly
  * Adapt timers helpers for multi-hosts
  * Make api_call not to recurse into IOLoop, add callbacks
  * Adapt worker registration to multihost
  * Adapt jobs helpers to non recursive api_call and multihost
  * New multihost workers.ini
  * Per-host working directory support
  * Multihost commands parsing
  * Adapt worker tests for non-blocking api_call
  * Use OpenQA::Utils log functions in worker
  * Use share/factory directory instead of factory link
  * Replace dirs parsing by one liners
  * Remove dead code
  * Use testcasedir helper instead of removed static
  * Add some unit tests
  * Fix generate/packed-assets not to require dbus session (#1186)
  * Avoid 404 errors on scheduled jobs
  * Take 4 travis jobs as success
  * needle editor: Validate needles/tags in JavaScript (#1189)
  * Reduce the number of travis jobs (#1188)
  * Duplicate the job if the worker is terminated
  * Simplify selenium using code
  * Do not do any jsonfile path processing
  * Prevent uninit ws variable warning
  * Pass query params as params key for duplicate
  * Allow api_call to be called without callback
  * Change the Mojolicious version requirements (#1195)
  * Fix needle path check (#1196)
  * Fix the 12-needle-edit test to leave the data in place
  * Import log_error before using it
  * Introduce project share directory variable
  * Adapt test to use share directory
  * Switch test distro from pitux to tinycore (#1203)
  * Fix last remnants of global url and ua usage
  * Add image upload to full stack test
  * AMQP: Declare exchange passive and durable (#1202)
  * Fix an error when job result is "setup failure"
  * Prepend sharedir when looking for needles with relpath (#1205)
  * Add full stack test for setup failures
  * Fix 24-worker.t
  * Fix build lookup for single groups (poo#15988) (#1204)
  * Allow override of the usual setting precedence order (#1200)
  * Fix undefined warning for _stop_job_finish (#1207)
  * Shared worker documentation
  * Document referrer configuration and label:linked
  * Fix job_timeout timer not being removed after stop_job (#1209)
  * Add get_timer getter for worker timers query
  * Add tests if start_job set proper timers and stop_job removes them
  * Improve code preparing data for test overview
  * Synchronize 'TODO' filter with review badges
  * Add help popover for 'TODO' filter
  * Show help popover details link in new tab
  * Enhance jobs list in worker page (#1212)
  * docs: Ensure pool dir exists when starting worker manually (#1213)
  * Fix UI test skipping when modules not available (#1211)
  * Avoid creating duplicit dependencies (#1214)
  * Update documentation for a more obvious flow (#1218)
  * branding: Add casp reporting links (#1219)
  * Add notice to clone_job.pl help text (#1222)
  * Do correct DISTRI-VERSION case dir lookup
  * Fix AMQP SSL wide character JSON encoding (#1224)
  * Refactor test for scheduler dependencies (#1225)
  * Fix apparmor profile to let worker read from /other (#1228)
  * Update GettingStarted for some Fedora repo changes (#1229)
  * Fix time display regression introduced by f127654
  * Harmonize running/scheduled time string also in UTC
  * Show absolute time in tests list for finished as well
  * Fix typo and make vhost config more readable
  * Update Pitfalls.asciidoc
  * Add pitfall for fake authentication method
  * docs: Correct asciidoc syntax for pool instance table
  * clone_job.pl: Display description with examples on '-h', too
  * Update create_admin script
  * docs: Improve language of 'using snapshots' section
  * Fix synchronization of TODO with badges
  * Add link from test details to assigned worker
  * Fix bugzilla links as CASP was renamed to CaaSP
  * docs: Delete reference to inactive stable repo (#1230)
  * needle editor: Fix errors appearing in JS console
  * needle editor: Show new tags in own line
  * needle editor: Display all tags in the same way
  * Allow configuration of how builds are sorted in web UI
  * Add id to comments over API to allow referencing
  * Fix needle editor when taking matches is disabled
  * Fix openqa_web docker instance running
  * Update Dockerfile to host openQA on Leap 42.2
  * Change deprecated "MAINTAINER" instruction
  * Add instruction "LABEL version"
  * Use the default openID provider
  * docker: Remove pool volume unused by webui
  * Fix error when running the worker container
  * Fix dockerfile for webui
  * Fix dockerfile for workers
  * Update README.md for docker section
  * Document running selenium UI tests (under Leap) (#1250)
  * Make needle edit test case less specific
  * Prevent double machine tag output in 02-iso.t
  * Add option for 'isos post' route to deprioritize old builds rather than obsolete
  * needle editor: Format new tags bold
  * needle editor: Prevent adding empty tag
  * docs: Add documentation for 'triggering tests'
  * Harden loading of auth modules with whitespaces (#1253)
  * Allow redirects for clone_job requests (eg to ssl)
  * Allow annonymous read access to operator tables
  * Fix failing admin test
  * Fix bugzilla reporting links for CaaSP
  * [docs]: added documentation about setting up ssl (#1257)
  * client script: Don't encode URL twice (#1260)
  * Allow api_call to be called without callback
  * Add Cache
  * Enable caching on the worker
  * Improve Cache package and tidy up the code
  * Fix cache.db problems
  * Ensure the asset has the proper name
  * Add TESTPOOLSERVER variable for caching
  * Refactor to allow CACHEDIRECTORY to replace share directory
  * Simplify api_call nesting
  * Fix the ISO expansion for local assets
  * Let's set reasonable goal for codecov
  * Work on testing cache
  * Do not exclude .git from syncing
  * Harmonize the keys used for assets
  * Add newlines to log output
  * Improve cache directory
  * Catch errors on cache downloads
  * Fix perlcritic errors
  * We need Mojolicious 7.24 for max_response_size
  * Implement download_asset so we can actually test caching it
  * Remove -E option from flock - we do not check the exit status
  * Make sure assets in pool are handled correctly
  * Add support for multiple group, no build on /tests/overview
  * docs: Add hint about multiple groups, no build
  * Call rsync of tests in a child process and notify webui
  * Move OpenQA::Cache to Worker namespace
  * Trying to make workers.ini more descriptive
  * docs: Add explanation for job priority (#1262)
  * Schedule worker reregistration in case of api-failure
  * Add more logging to job notifications
  * Use host_port when parsing URL
  * Prevent various timer loops
  * Do job cleanup even in case of api failure
  * Ensure uploaded assets have correct perms (#1263)
  * Change $testpoolserver only if passed as option (#1264)
  * Set read permissions for downloaded assets (#1267)
  * Ignore module flag 'important' (#1266)
  * product log: Don't show actions when not at least operator
  * Make assets, workers and API help publicly available
  * needle editor: Fix inserting tag via middle mouse button (#1269)
  * Fix restarting jobs from worker page (#1272)
  * Merge 'Status' and 'Connected' columns in workers overview (#1273)
  * Add anchor for build results on index page (#1265)
  * Lower down quantity of automatic carryover
  * Add environmental variable to skip online tests
  * Be specific which text element we want to test
  * Fix hardcoded cache.db file
  * Fix assets not being removed
  * Force read_db after a write
  * Add subtest for Cache
  * Improve log output for label carryover
  * Ensure that label carryover is done correctly
  * Fix the recursive $db_file appending (#1279)
  * Tidy the code after last hot fix
  * Relax the regex for build values in tag: comments again
  * Don't obsolete jobs for VERSION-BUILD tagged builds
  * needle editor: Distinguish tag/area selection in check
  * needle editor: Test verification when not copying areas
  * Improve little triangle sign below a screenshot (#1285)
  * Add ignores for db.lock and phantomjs log (#1287)
  * Correct 'softfailed' reference to passed (obsoleted)
  * Ensure consistent naming of 'failed'+'softfailed' in all occurrences
  * Fix overriden shared $dir worker registration (#1291)
  * Add a Contributing section
  * Add explicitly index and current.pdf
  * Stop distinguishing softfailures
  * Fix typo 'parallel' (#1290)
  * Adjust grid wrapping in build tables (#1286)
  * Use space indendation consistently in javascript files
  * Delete w/s at EOL in javascript files
  * Add 'build-results' anchor for group-overview page, too (#1281)
  * Replace old 'important' behaviour with 'ignore_failure' (#1297)
  * Give failed screenshots back the red border (#1300)
  * Adjust test module flags on Details page for ignore_failure (#1299)
  * Document the 'norollback' flag in WritingTests (#1298)
  * Better error msg for openqa client (#1303)
  * Improve 'Downloading failed' message (#1302)
  * Refactor 05-scheduler-dependencies.t (#1306)
  * Shorten build-numbers with dots to prevent overlapping (#1305)
  * Fix "only tagged" for tags with version (#1296)
  * Do not upload empty serial_terminal.txt (#1274)
  * Makefile: Allow to skip checkstyle (#1304)
  * Fix missing space in log debug message (#1307)
  * Register job assets even if one of the assets need to be skipped (#1310)
  * Test whether admin table displays needles which never matched
  * Show needles in admin table which never matched
  * Improve logging in case of upload failure (#1309)
  * Improve product fixtures to prevent dependency warnings
  * Handle wrong/missing job dependencies appropriately
  * clone_job.pl: Print URL of generated job for easy access (#1313)
  * Allow lscpu to read all of /proc - but only lscpu (#1315)
  * clone_job.pl: Skip downloading generated assets in all cases (#1314)
  * Fix invalid HTML
  * Don't use name attribute on div element for markdown
  * Fix indentation in overview.scss
  * Fix showing long needle name in hover popup
  * Prevent DB exception when adding tests in job templates (#1318)
  * Remove duplicate "current step" (#1319)
  * Refactor Cache.pm to use SQLite instead of json
  * Update cache full stack test
  * Fix minor race condition
  * Increase test coverage
  * Use cache.sqlite instead of cache.db
  * Detect and set current version of openQA,  display it in the footer (#1316)
  * Add service file for workers with "no cleanup" (#1320)
  * Prevent tags from getting cut by long build numbers (#1321)
  * clone_job.pl: Fix generated job URL to be the receiving host (#1326)
  * Unlink existing asset symlinks on syncing (#1323)
  * Move OpenQA::Test::* modules to test directory (#1325)
  * Improve admin test (#1327)
  * Fix makefile syntax (#1328)
  * Avoid line break after h4 in midori and co (#1333)
  * Implement a config option to restart workers that grew too big (#1339)
  * Allow cache to handle 5XX errors and retry 5 times (#1337)
  * Inspect failed modules in /tests/overview (#1335)
  * Fix print() on closed filehandle $log (#1334)
  * Replace file_content() with Mojo::File (#1331)
  * Disable printing time when logging to STDERR
  * Add more tests to configuration parsing
  * Fix bugzilla reporting link for SLE-12-SP1 (#1332)
  * Make 'TEST' the only proper mandatory test setting (#1126)
  * Avoid unit test to write on source code directory (#1341)
  * Fix breakage introduced by https://github.com/os-autoinst/openQA/commit/659464d19b02e541f2529bd313c39681c71adfcf (#1343)
  * Add scheduler test to cover OpenQA::Scheduler::FakeApp (#1345)
  * Fix documentation publishing on gh-pages
  * Make sure a valid up-to-date license in all files
  * Fix doc generation - testapi (#1347)
  * Add unit test to fix codecov "uncovered changes" (#1348)
  * Add direct link to video position (poo#19300) (#1342)
  * Avoid github and use a CDN for chosen.jquery (#1350)
  * Correct Typo in Firewall config file (#1351)
* Thu May 18 2017 mlin@suse.com
- Prerequire needed group nogroup
* Thu May 18 2017 slindomansilla@suse.com
- Also provide systemd services for workers with '--no-cleanup'
* Thu May 18 2017 rd-ops-cm@suse.de
- Update to version 4.4.1495052041.c6a5bc94:
  * Remove duplicate "current step" (#1319)
  * Fix minor race condition
  * Increase test coverage
  * Use cache.sqlite instead of cache.db
  * Detect and set current version of openQA,  display it in the footer (#1316)
  * Add service file for workers with "no cleanup" (#1320)
  * Prevent tags from getting cut by long build numbers (#1321)
  * clone_job.pl: Fix generated job URL to be the receiving host (#1326)
  * Unlink existing asset symlinks on syncing (#1323)
  * Move OpenQA::Test::* modules to test directory (#1325)
* Sat Mar 18 2017 coolo@suse.com
- bump mojo requirement
* Sat Mar 18 2017 rd-ops-cm@suse.de
- Update to version 4.4.1489864450.251306a:
  * Make sure assets in pool are handled correctly
  * Call rsync of tests in a child process and notify webui
  * Move OpenQA::Cache to Worker namespace
  * Trying to make workers.ini more descriptive
  * docs: Add explanation for job priority (#1262)
  * Schedule worker reregistration in case of api-failure
  * Add more logging to job notifications
  * Use host_port when parsing URL
  * Prevent various timer loops
  * Do job cleanup even in case of api failure
* Thu Jan 19 2017 santiago.zarate@suse.com
- Add the openQA.changes file to be distributed as public/Changes on the web-ui
* Wed Jan 18 2017 rd-ops-cm@suse.de
- Update to version 4.4.1484732113.4fb90841:
  * Document filtering
  * Fix documentation generation (#1177)
  * Fix corner buttons (#1176)
  * utils: Add kernel bugzilla bugref (#1175)
  * Do not run tests for GH_PUBLISH=true
  * Mojolicious 7.19 has broken SSL support - blacklist it
  * Switch to CDN for fontawesome
  * Fix missing images in documentation (#1180)
  * Do not even run the coverage target if GH_PUBLISH is true (#1183)
* Thu Jan 12 2017 coolo@suse.com
- bump requirements to Mojo and AssetPack
* Thu Jan 12 2017 okurz@suse.com
- add Sort::Version requirement
* Thu Jan 12 2017 rd-ops-cm@suse.de
- Update to version 4.4.1484213177.5ef2a6e4:
  * Add css class to click on action (#1147)
  * client: Support sending JSON data (#1150)
  * Test both phantomjs and chrome on travis
  * Exclude AssetPack >= 1.30 - it will break fonts
  * Sort build versions correctly (#1136)
  * Add optional profiling support using Mojolicious::Plugin::NYTProf (#1153)
  * Add tests for client script
  * Don't use config file as database lock file (#1157)
  * Fix build of the package: we need a db directory to lock now
* Thu Dec 22 2016 coolo@suse.com
- remove YAML and Socket::IO::INET6 dependencies
* Wed Dec 21 2016 rd-ops-cm@suse.de
- Update to version 4.4.1482329765.866bba8:
  * Improve buttons in interactive mode
  * Fix command API route
  * Synchronize INTERACTIVE and STOP_WAITFORNEEDLE_REQUESTED
  * Change the format for developing with snapshots (#1093)
  * Fix sorting of needle table (#1092)
  * Add short route to individual job results '/t:testid:' (#1089)
  * doc: fix typo (#1096)
  * Fix AMQP reconnect timeout config var (#1098)
  * Add AMQP connection error msg to log (#1099)
* Thu Dec 15 2016 coolo@suse.com
- add new require on time::parsedate
* Thu Dec 15 2016 rd-ops-cm@suse.de
- Update to version 4.4.1481828911.8296cb4:
  * Update worker apparmor file from production worker log (#1078)
  * Add brc (Red Hat Bugzilla) and bgo (GNOME Bugzilla) labels (#1083)
  * Auditlog: display event time on hoover
  * Auditlog: add page and rows query options
  * Switch audit log to server side processing
  * Use system user to create system events
  * Add new Time modules dependencies
  * Add page displaying single event
  * Improve search query parser to support multi-word queries
  * Don't bother with event data shortening
* Fri Dec  9 2016 coolo@suse.com
- add bcond_with tests to run phantomjs optionally
* Fri Dec  9 2016 rd-ops-cm@suse.de
- Update to version 4.4.1481216307.2d2b18a:
  * worker: Prevent use of uninitialized value (#1066)
  * Copy over policies from os-autoinst
  * Fix usage of qw(SINGLE_VALUE) in use statements
  * Rework websocket server (#1057)
  * client: Respect --json also in case of an error (#1068)
  * client: Set 'Accept'-header in any case (#1070)
  * Return 404 on status update for job without worker
  * worker: Abort job if considered dead by web UI
  * Improve misleading comment
  * Comment events: Drop unneeded fedmsg conditional, include id (#1065)
  * Improve log message when job considered dead (#1075)
  * Disable carry-over for job 'labels' to support new use cases (#1071)
* Mon Nov 28 2016 oholecek@suse.com
- Do not package removed files script/migrate_images and backlog
* Mon Nov 21 2016 rd-ops-cm@suse.de
- Update to version 4.4.1479741639.90bdf0f:
  * external_reporting: Fix differing header level in description (#1012)
  * Add test for parents on index page and parent group overview (#1015)
  * Show build tags on parent-level (#1018)
  * Add a 120 column limit to .perltidyrc (#1017)
  * Fix a few formatting mistakes and remove repetitive method calls (#1020)
  * docs: Update openSUSE repos to current supported (#1021)
  * Fix URLs in dashboard when version/distri differ (#1024)
  * Show submenus on click (#1025)
  * Update bootstrap to 3.3.7
  * Wait a bit in tests if there is an ajax call
* Tue Nov  8 2016 coolo@suse.com
- update cache for bootstrap-submenu
* Tue Nov  8 2016 rd-ops-cm@suse.de
- Update to version 4.4.1478599354.3d748dc:
  * Fix job group overview without description (#957)
  * Don't free worker before artefacts are uploaded (POO #14378) (#958)
  * Improve override needle test (#962)
  * Use textareas in test suite editor (#961)
  * Fix worker error reporting when asset cannot be found (#963)
  * Make .json easier to use and include more data (#965)
  * Add API routes for job group parents (#952)
  * Hide empty job groups from index page (#967)
  * Optionaly inherit command line variables in parent (#951)
  * Add gzip and rsync to worker's AppArmor (#968)
  * Only store md5_dirname if the image is in /images (#959)
  * Fix malformed HTML
  * Fix malformed HTML (#970)
  * Prepare CACHEDIRECTORY example in workers.ini and provide profile (#969)
  * Implement Drag & Drop group editor
  * Add support for github 'bugrefs'
  * t: Delete unused (disabled) 'use Test::Output'
  * t: Ensure proper output catching
  * Improve usability of job group property editor
  * Replace all '...' with '…' in web UI
  * Add assert_script_run description
  * Allow '@' in asset name (#979)
  * Fix list of needle tags in needle info popover (#977)
  * Allow worker profile to access fixed assets
  * Fix download of fixed assets from web UI
  * Reindent 01-jobs fixtures
  * Use url helpers to map the asset path to URL
  * Add help text using popovers, title and placeholder (#983)
  * Add missing argument for hmac timestamp validation
  * Give tests without fails a no-TODO tag (#960)
  * Trying to make peace with adamw over locate_asset
  * Add a repository as test fixture to test subpaths
  * Show tags on index page
  * Add API auth tests
  * Improve help popups
  * isotovideo: Remove redundant '|| undef' (#989)
  * branding: openqa.suse.de: Update staging to current SP3 (#988)
  * Show parent groups in navbar (#974)
* Thu Oct 27 2016 coolo@suse.com
- have openqa_worker own /var/lib/openqa/cache
* Thu Oct 27 2016 rd-ops-cm@suse.de
- Update to version 4.4.1477579540.21d4009:
  * Use textareas in test suite editor (#961)
  * Fix worker error reporting when asset cannot be found (#963)
  * Make .json easier to use and include more data (#965)
  * Add API routes for job group parents (#952)
  * Hide empty job groups from index page (#967)
  * Optionaly inherit command line variables in parent (#951)
  * Add gzip and rsync to worker's AppArmor (#968)
  * Only store md5_dirname if the image is in /images (#959)
  * Fix malformed HTML (#970)
  * Prepare CACHEDIRECTORY example in workers.ini and provide profile (#969)
* Sat Oct 22 2016 rd-ops-cm@suse.de
- Update to version 4.4.1477110901.763fe71:
  * Step controller: split init into 2 functions
  * Fix coverage skipping files with 't/' in path
  * Test source view from running
  * Treat #details tab as all the others to fix back button
  * Add test for switching tabs in tests result view
  * Some fixes for the new results / running page
  * Fix SQL query to query important jobs
  * docs: Update OBS references
  * Upgrade to Leap 42.1, and fix apache2 starting problem
  * Live view: simplify drawImage
  * Be way more careful with history manipulation on results page
  * Treat # and '' the same for history management
  * Allow sha1sum for os-autoinst:2144a20c
  * Allow git for os-autoinst:d29266f
  * clone_job.pl: Add option '--skip-download'
  * Give the user better hints on what we expect for the expiry date
  * Do not create a link_post for reschedule isos
  * Use the proper API to get the data of the selected row not the first row
  * Replace the broken PNGed SVG with the real one
  * Talk to os-autoinst through HTTP instead of the file system
  * Replace document.ready with $(fn)
  * Fix interactive buttons
  * Fix upload of images during needinput
  * Make sure the worker stops at signals
  * Fix spelling of existent
  * Add web UI controls to select 20/50/100/400 previous results
  * limit_assets: when sizelimit is exceeded, remove more
  * Be more graceful when stopping the backend
  * Always set a t_finished to now if the job has a final state
  * Sort the finished jobs by their finished time
  * Change the order of the tests in the list test
  * Set a t_finished time in fixtures to have predefined order of finished jobs
  * Sort the scheduled jobs based on time
  * Sort the running jobs by Start time
  * Benefit from the hashsum calculation for our icons too
  * Remove pauseplay class and image - no longer used
  * Add more icons to assets and remove what's left in public/images
  * Remove dead file
  * Add custom whitespace squish
  * Use manual whitespace trimming after squish was removed from Mojo7
  * Mojo7 removed Mojo::URL::authority, use host_port instead
  * Add SUSE internal branding with more links
  * Refresh running modules in #details view
  * Deal with race conditions when refreshing #details
  * Create missing results tbl on #details
  * Reload broken thumbnails on test #details
  * Correct description for use of OPENQA_CONFIG
  * Fix build tagging when @ is used
  * Clarify comment in the dashboard test
  * Use correct job result in openqa events
  * Add command_enqueue to worker model as send_command
  * Export log_error helper in OpenQA::Utils
  * Add job_set_done and job_cancel to Jobs module and result set
  * Adapt tests for moved job_set_done and job_cancel
  * Remove scheduler dbus exports and subs job_set_done and cancel
  * Remove command_enqueue from scheduler and dbus
  * Check for user when emitting event
  * Log iso_cancel for canceled jobs due to new iso and allow job_cancel_by_settings event
  * Fix typo in worker check during job duplication
  * Fix counting of cancelled jobs
  * Update Jobs::cancel to accept $obsoleted option
  * Use ws_call using well known format to send messages to WS server
  * Sync property parsing to workers format
  * Make softfailed a proper final result
  * Add tests for showing softfails in prev results
  * Give user_restarted an explicit colour
  * Remove MySQL from deployments, we never test migrations or deployments
  * Resort to raw SQL instead of avoiding the schema and still use dbic
  * Fix DB access error when skipping scheduled children
  * Test both children skipping and stopping
  * Accept softfail result as passed
  * Add test scenarios for job result calculating
  * apparmor: Add missing /usr/lib/git/git
  * Make softfailed tests show the right colour
  * Make non-important failures at least a general softfail
  * Calculate softfailed at the very end to fix one specific case
  * Add more tests for corner cases
  * Carry over also for incomplete and softfailed
  * Add V1 API for comments
  * Use API for comments in web UI
  * Add comments without reloading page
  * Only redirect to running tab when no # is in url
  * Clear url hash on test step result preview close
  * Test for url hash cleanup after preview close
  * Fix incorrect 21-admin-needles test
  * Fix calculate_result (again): $overall should cover all
  * Improve error handling of comment API
  * Prevent needle editor flickering (progress #12984)
  * Enforce build order for group overview in tests
  * Remove unneeded functions of old comment API
  * Add 'latest' query route
  * Remove history for step navigations
  * Replace job_set_done by $job->done in dead job handler
  * Move dead worker check to websocket server
  * Add test for dead worker detection
  * Make build in previous view a link to tests overview
  * Add test for 'todo=1' query param
  * t: Fix typo in t/ui/18-tests-details.t
  * Fix deadworker timer function reference
  * Fix complex_query and its usage in last route
  * Render links on 'latest' route directly instead of redirect
  * templates: Simplify single line statements
  * Make title for 'previous results' a proper heading
  * t: 12-needle-edit.t: Try to find overwrite warning more often (poo#12980)
  * previous: Move current limit where other options are
  * Add web UI controls to select more builds in group_overview
  * Add web UI controls to filter only tagged or all builds
  * Fix workaround label
  * Fix taking over tags from a workaround needle
  * worker: Remove tons of work arounds and quirks in upload
  * Allow cksum to be called in the worker
  * Upload assets as temporary files and only rename after chksum check
  * Fix typo
  * Prevent use of non-existing route in upload_status
  * templates: live: Fix url_for over 'latest' route
  * Disable auto-duplication of jobs (poo#13042)
  * Avoid shift
  * Test handling deleted needles in needle editor
  * Ignore deleted needles when showing needle editor
  * Show warning about deleted/bad needles (needle editor)
  * Fix admin layout for test suites with long keys Currently test suites slenkins-tests-ceph-control and s390_hsi-l2
  * Make apache follow symlinks for assets directory
  * Fix '0' duration for previous jobs on running or scheduled job
  * Add link to latest job in each scenario
  * Allow pinning comments as group description
  * Fix jobs templates layout
  * Also filter 'machine' on latest
  * Vertically align progress bar with build number
  * Re-add boundary hack
  * Make 'latest' link more explicit
  * Do not quote identifiers, solves problem with uppercase column (#838)
  * use /var/lib/openqa/share/factory/iso path (#849)
  * Add 'bash' to be able to run 'CMD' (#850)
  * Add filter from in test overview (#852)
  * Draw needle match labels after match boxes (#851)
  * Add lock barriers (#845)
  * Show custom error pages (#831)
  * README: Update coveralls icon by .svg version (#853)
  * Add new job state (#848)
  * Remove old comment code (#856)
  * Run optipng on the worker while uploading images (#858)
  * Add filter for all states and results
  * Distinguish comment events
  * Show results and states dynamically
  * Test whether job still exists in reduce_result
  * Split Logging support out of WebAPI (#860)
  * Give the scheduler a home (#862)
  * Log status update without worker (#861)
  * dead worker check: use 15 secs not 10, better names, comments (#864)
  * Fix the stale job calculation for uploading jobs (#865)
  * Fix path in docs about migrating db schema
  * Show filter on top and display current filter
  * Avoid HMAC timestamp mismatch during large file upload (#871)
  * Give Websockets and Scheduler the home of the webapi (#870)
  * Label builds where all tests passed as reviewed
  * Dont grab twice (#874)
  * Prevent detecting occurrences like bsc#2436346bla as bugref
  * Replace URLs with the appropriate bugref pattern
  * Do not rely on WebAPI to find home - require and use an harmless class (#876)
  * Prevent multiple bug refs per comment to yield incorrect URLs
  * Add 'match' query parameter for index page
  * Add 'group' query parameter for index page
  * Add more faking to FakeApp - so restarting jobs works again (#880)
  * comment the home detection for scheduler/websockets better
  * Allow bugrefs being separated by any non-word chars
  * Fix used needle indication when needles are in folders
  * Merge match and group parameter
  * Use $FindBin::RealBin to resolve links for client script (#889)
  * Fix previous jobs showing up for different machine (#885)
  * Remove FIXMEs and disabled code in t/ui/15-comments.t (#888)
  * notify workers when job with chained children done (POO #13746) (#883)
  * Pass encoded URL filter parameter correctly (#890)
  * Reintegrate job duplicate (#875)
  * Mark worker alive for all kind of artefacts (#894)
  * Small schema change to add an index (#895)
  * Add IPC debug to websockets too to debug hangs (#896)
  * update apparmor profiles for ppc64le (#892)
  * Try harder to avoid long running pre-processing (#897)
  * Increase session expiration from 1 to 48 hours (#900)
  * Make ws_send_all WebSocket call not waiting for results (#902)
  * Avoid DBUS dead locks (#901)
  * Do not manually render anything on websocket creation (#903)
  * Prevent error message in log as 'scheduled' jobs are also 'inprogress' (#906)
  * Add scenario params to limit URLs for previous results (#893)
  * Handle links to bugs already formatted correctly (#905)
  * Improve documentation about PosgreSQL (#904)
  * Test time_limit_days query parameter (#907)
  * Fix comments test (#908)
  * Split the images directory even more (#739)
  * Add anchor links to comments (#909)
  * Move comments.css to sass reduce copy&paste (#910)
  * Readd the lost name of the thumb_nail route (#911)
  * Refactor computing build results (#898)
  * Show incomplete/skipped bugs, show tooltip on progress bars (#912)
  * Add link to openQA review (#899)
  * Fix vertical alignment of progress bars in tables (#917)
  * Show progress indication in admin needle table (#918)
  * Track image assets better (#919)
  * Fix deletion of multiple needles at once (#921)
  * fix downloading assets to different filename
  * Fix sorting in admin needle table (#924)
  * Add JSON representation of index and group overview (#922)
  * Add filter form for index page (#923)
  * Add /index.json route and test it together with overview.json (#925)
  * Fix /index.json route to pass the format (#926)
  * Fix softfailed results not showing in tests list (#930)
  * Fix group filter on index when param is empty (#933)
  * Fix group overview when no builds shown (#932)
  * t: Add 'Test::Warnings' where missing; Catch all warnings in tests again (#931)
  * Extend schema of JobGroups (#914)
  * Fix typos (#935)
  * reuse a constant boundary to make debugging failed uploads a little easier (#934)
  * Some code cleanup and more tests (#937)
  * Fix test result info spacing (#938)
  * fix loch ness monster bug in 14-grutasks.t (#941)
  * Load step and needles for failedmodules link async (#936)
  * Complete API for job groups (#942)
  * Auto reload result page on state sched -> running (#940)
  * Update Installing.asciidoc (#927)
  * Go to bugzilla.suse.com also for bnc# (#943)
  * Fix going to bugzilla.suse.com also for bnc# (#946)
  * Improve error handling when deleting needle (#939)
  * Fix needle deletion via Git (#948)
  * WebAPI: Delete comments stating the obvious + delete unused routes (#947)
  * Render bugref links in thumbnail text windows
  * Test render bugref links in thumbnail text windows
  * Show job group description (#950)
  * Add 'fixed' asset subdirectories for fixed assets (#928) (#945)
  * use locate_asset in register_assets_from_settings (#954)
  * Rejig compressed asset download, don't leave compressed files (#955)
  * Fix registration of downloaded assets (broken by 0905559b) (#953)
  * List needle tags + step icons (#944)
* Tue Sep 20 2016 oholecek@suse.com
- Add missing dependency perl(JSON) for openqa-client
* Mon Sep 19 2016 oholecek@suse.com
- Add missing dependencies perl(Data::Dump) and perl(Getopt::Long)
  for openqa-client
* Sat Sep 17 2016 oholecek@suse.com
- Add symlink /usr/bin/openqa-client to /usr/share/openqa/script/client
* Thu Sep  8 2016 oholecek@suse.com
- Ghost /var/lib/openqa/share in common subpackage
  * solves issues when updateing worker with mounted NFS
* Mon Aug 22 2016 oholecek@suse.com
- Remove perl(Perl::Critic) build requirement, added by mistake
* Mon Aug 22 2016 oholecek@suse.com
- Package /var/lib/openqa/share for common subpackage
- Pakcage /var/lib/openqa/share/factory/[iso|hdd|other|..] for openQA package
* Sat Jul  9 2016 coolo@suse.com
- Update base version to 4.4 to express new API of isotovideo
* Mon Jun 20 2016 rd-ops-cm@suse.de
- Update to version 4.3.1466434215.021a11c:
  * No longer export the worker_id as hash entry
  * Remove job_get from the scheduler
  * Simplify our theme - split the sass theme from the specifcs
  * Set an explicit colour on cancelled
  * Use default bootstrap table class for striping
  * Use the theme colour in tables
  * Have our bootstrap theme based on https://bootswatch.com/paper/
  * Fix comments test - h2 is the new h1
* Wed Jun  1 2016 rd-ops-cm@suse.de
- Update to version 4.3.1464792258.155f49e:
  + t: Use helper function to wait for ajax
  + Extend iso post TEST parameter to support a list of tests (poo#10482)
  + Test for "let TEST parameter support a list of tests"
  + Enable brackets inside keys in client script
  + Add first approach for editable comments
  + Make comments for tests editable, too
  + Fix indentation of flash and wells on test page
  + Fix minor mistakes in editable comments
  + Reduce code-dublication in templates
  + Add first approach to test editable comments
  + Test comment editing in test results, too
  + Check for current user in commenting functions
  + Adjust t/17-labels_carry_over.t to reflect changes
  + Add css class no_hover to all /thumbs/
  + Improve TEST parameter to support a list of tests
  + needlediff: Improve similarity text look
  + Use the nice audio icon (with the correct size)
  + Use nice icon for wait_serial
  + add a config setting to specify asset types not to link to
  + Increase left padding of status icons
  + Prevent error in group_overview with '-important' builds
  + Check database configuration with better user feedback
  + Fix broken string compare slipping into wait_serial icon change
  + Fix non-ASCII characters in comments
  + Allow admins to delete any comments
  + Fix showing editing buttons
  + Fix regexp for multiple parent jobs
  + Fix typo in 05-scheduler-restart-and-duplicate.t
  + Improve log message about 'setup failure'
  + Support tests/export to get a text format for archives
  + Fix re-enabling current user role
  + Adapt to latest AssetPack
* Sun Apr 10 2016 oholecek@suse.com
- add perl(Archive::Extract) dependency (needed by PR#627)
* Tue Mar 22 2016 oholecek@suse.com
- create openQA-client and openQA-doc subpackages
- remove DB handling, it's done by openQA itself now
* Wed Feb 17 2016 coolo@suse.com
- adapt to adam's changes
* Mon Feb 15 2016 lnussel@suse.de
- remove user migration code. no such systems should exist anymore
* Thu Jan 14 2016 oholecek@suse.com
- update base version to 4.3
* Fri Jan  8 2016 oholecek@suse.com
- add modify_needle script
* Mon Oct 26 2015 oholecek@suse.com
- add create_admin script
* Tue Sep  8 2015 oholecek@suse.com
- add perl(IPC::Run) dependency (needed by PR#414)
* Mon Aug 31 2015 lnussel@suse.de
- we don't need JSON::RPC::Legacy::Client
* Mon Jul  6 2015 lnussel@suse.de
- fix rpmlint warnings
* Wed Jul  1 2015 oholecek@suse.com
- add openqa-scheduler.service and openqa-websockets.service
* Wed Jun 24 2015 lnussel@suse.de
- fix fileliist for missing service files
* Wed Jun 17 2015 oholecek@suse.com
- package dbus system policy config
- add perl(Net::DBus) to requires
* Wed Apr  8 2015 coolo@suse.com
- add openqa-gru.service
* Wed Mar 18 2015 lnussel@suse.de
- keep /lib/openqa/share in webui and the symlink in -common. So a
  plain worker owns no files in share
* Mon Mar  9 2015 lnussel@suse.de
- add --from=geekotest to chown call just to be on the safe side
* Mon Mar  9 2015 coolo@suse.com
- create a 2nd user and migrate the worker from geekotest to
  _openqa-worker
* Sat Feb 28 2015 coolo@suse.com
- run preparetool from the right %%post
* Thu Feb 26 2015 oholecek@suse.com
- fix missing ini files link and package new config dir (boo#919548)
* Wed Feb 25 2015 sfalken@opensuse.org
- Changed path for fetchneedles in post-install echo
* Mon Feb 23 2015 oholecek@suse.com
- don't move ini files in spec, Makefile does it now
* Thu Feb 19 2015 lnussel@suse.de
- include fetchneedles in file list
* Tue Feb 17 2015 rd-ops-cm@suse.de
- Update to version 4.1424166204.2ca1601:
  + Refactor worker scripts and add locking support
  + Pass worker port to os-autoinst and remove :jobid check
  + assets replaced /diskimages long ago - get rid of it
  + avoid "openQA: openQA" as title on main page - looks just silly
  + remove lib/OpenQA from include path - not needed
  + fix make test to be coverable and use it in .travis.yml
  + switch default auth_module to Fake
  + adding a test to test /admin/machines using phantomjs
  + skip the tests if phantomjs is not installed
* Fri Feb 13 2015 oholecek@suse.com
- we don't need MojoX::JSON::RPC
* Thu Jan 29 2015 lnussel@suse.de
- reduce mojo require to 5.60
* Wed Jan 28 2015 lnussel@suse.de
- require qemu in worker to get kvm group
- add geekotest user to kvm group in worker's %%post as qemu is not required by
  the web ui
* Wed Jan 28 2015 coolo@suse.com
- fix requires
* Wed Jan 28 2015 coolo@suse.com
- make it version 4 and require os-autoinst of version 4 too
* Fri Jan  9 2015 oholecek@suse.com
- add BuildRequire perl(Test::Compile)
* Sun Dec 21 2014 lnussel@suse.de
- pre-require openQA-common to make sure the user is created
* Sun Nov 30 2014 coolo@suse.com
- we don't require png2theora any longer - and actually openQA-worker
  never did
* Mon Nov 17 2014 oholecek@suse.com
- fix upgrade scenario from openQA to openQA-common
* Thu Nov 13 2014 oholecek@suse.com
- split to openQA, openQA-common and openQA-worker packages
* Thu Oct 30 2014 mlin@suse.com
- fix post script - remove buildroot macro
* Fri Aug 29 2014 lnussel@suse.de
- don't enable systemd files in %%post!
* Tue Aug 12 2014 dvlaeev@suse.com
- Build as noarch package
* Fri Aug  1 2014 lnussel@suse.de
- require git-core as it's needed by testsuite
* Thu Jul 17 2014 oholecek@suse.cz
- add perl(aliased) requirement
* Wed Jun 25 2014 lnussel@suse.de
- remove apache conf.d file
* Thu Jun 12 2014 lnussel@suse.de
- create log file in package
* Tue May 20 2014 lnussel@suse.de
- restart boot.apparmor on update
* Mon May 19 2014 lnussel@suse.de
- disable tidy test
* Wed May 14 2014 lnussel@suse.de
- recommend instead of require apparmor
- restart apparmor on update
* Wed Apr 30 2014 lnussel@suse.de
- load_dbdata no longer needed
* Fri Apr 11 2014 alarrosa@suse.com
- Load the data for the opensuse usage case into the database during %%post
* Tue Apr  8 2014 alarrosa@suse.com
- Added a dependency on perl(YAML) which is required by initdb and upgradedb
* Mon Apr  7 2014 alarrosa@suse.com
- upgrade.pl was renamed to upgradedb
* Mon Apr  7 2014 alarrosa@suse.com
- require perl(SQL::SplitStatement)
- Initializes or upgrade the database as needed in %%post
* Fri Mar 28 2014 lnussel@suse.de
- require perl(DBIx::Class::DeploymentHandler)
- add /var/lib/openqa/cache to file list
* Thu Mar 27 2014 lnussel@suse.de
- use prove instead of make test
* Thu Mar 27 2014 lnussel@suse.de
- add GHC, Mojolicious::Plugin::CHI and Cache::Cache as dependency
* Fri Mar 21 2014 mhrusecky@suse.cz
- rc symlinks for webui and workers
* Fri Mar 21 2014 coolo@suse.com
- fix dependencies on JSON client
* Mon Mar 17 2014 coolo@suse.com
- change version format in _service file
* Fri Mar 14 2014 coolo@suse.com
- move the openqa.ini to /etc and mark it noreplace
* Wed Mar 12 2014 coolo@suse.com
- require perl(LWP::Protocol::https) for openid support
* Wed Mar 12 2014 coolo@suse.com
- bump version to 3 so we can differ it from v2
- require systemd and old JSON::RPC - needs porting
* Wed Mar 12 2014 coolo@suse.com
- install apache templates and enable the systemd services
* Thu Mar  6 2014 lnussel@suse.de
- add perl(Image::Magick) requirement
* Tue Mar  4 2014 lnussel@suse.de
- add perl(Net::OpenID::Consumer) requirement
* Mon Mar  3 2014 lnussel@suse.de
- add perl(DateTime::Format::SQLite) requirement
* Fri Feb 28 2014 lnussel@suse.de
- add systemd macros
* Mon Feb 24 2014 mlin@suse.com
- update the fileslist and the post script
* Mon Feb 24 2014 mlin@suse.com
- require Date::Format and File::Copy::Recursive
- update the filelist
* Mon Feb 17 2014 lnussel@suse.de
- require SQL::Translator
* Wed Feb 12 2014 mlin@suse.com
- add openQA's apparmor profile usr.share.openqa.script.openqa
* Wed Feb 12 2014 mlin@suse.com
- add perl(Config::IniFiles) as Requires
- remove /etc/default/openqa
* Thu Feb  6 2014 lnussel@suse.de
- fix filelist and run testsuite
* Wed Jan 22 2014 coolo@suse.com
- use remote services to hook
* Fri Jul 26 2013 lnussel@suse.de
- update to git head, add new requirement File::Copy::Recursive
* Thu Jun 13 2013 lnussel@suse.de
- use primary group "nogroup"
* Tue May 14 2013 lnussel@suse.de
- initial package
